@@ -37,6 +37,8 @@ static INTRINSICS0: phf::Map<&'static str, NamedFn0> = phf_map! {
     "type" => NamedFn0 { name: "type", func: get_type },
     "length" => NamedFn0 { name: "length", func: length },
     "utf8bytelength" => NamedFn0 { name: "utf8bytelength", func: utf8_byte_length },
+    "keys_unsorted" =>  NamedFn0 { name: "keys_unsorted", func: keys_unsorted },
+    "keys" =>  NamedFn0 { name: "keys", func: keys },
     "sort" => NamedFn0 { name: "sort", func: sort },
     "reverse" => NamedFn0 { name: "reverse", func: reverse },
     "tostring" => NamedFn0 { name: "tostring", func: text },
@@ -160,6 +162,34 @@ fn utf8_byte_length(context: Value) -> Result<Value> {
     }
 }
 
+fn keys_unsorted(context: Value) -> Result<Value> {
+    match context {
+        Value::Array(arr) => Ok((0..arr.len()).map(Value::number).collect::<Array>().into()),
+        Value::Object(obj) => Ok(obj
+            .keys()
+            .map(|k| k.to_string().into())
+            .collect::<Array>()
+            .into()),
+        _ => Err(QueryExecutionError::InvalidArgType(
+            "keys_unsorted",
+            context,
+        )),
+    }
+}
+
+fn keys(context: Value) -> Result<Value> {
+    match context {
+        Value::Array(arr) => Ok((0..arr.len()).map(Value::number).collect::<Array>().into()),
+        Value::Object(obj) => Ok(obj
+            .keys()
+            .sorted()
+            .map(|k| k.to_string().into())
+            .collect::<Array>()
+            .into()),
+        _ => Err(QueryExecutionError::InvalidArgType("keys", context)),
+    }
+}
+
 fn has(context: Value, index: Value) -> Result<Value> {
     Ok(match (context, index) {
         (Value::Array(arr), Value::Number(n)) => {
