@@ -1,5 +1,4 @@
 use crate::{
-    lang::ast::Identifier,
     util::make_owned,
     vm::{bytecode::NamedFn0, QueryExecutionError, Result},
     Array, Number, Value,
@@ -20,8 +19,8 @@ pub(crate) fn to_number(value: Value) -> Result<Value> {
     }
 }
 
-pub(crate) fn stringifier(id: &Identifier) -> Option<NamedFn0> {
-    match id.0.as_str() {
+pub(crate) fn stringifier(fmt: &String) -> Option<NamedFn0> {
+    match fmt.as_str() {
         "text" => NamedFn0 {
             name: "text",
             func: text,
@@ -98,6 +97,21 @@ pub(crate) fn implode(value: Value) -> Result<Value> {
     }
 }
 
+pub(crate) fn split(lhs: &String, rhs: &String) -> Value {
+    if rhs.is_empty() {
+        lhs.chars()
+            .map(|c| c.to_string().into())
+            .collect::<Array>()
+            .into()
+    } else {
+        lhs.split(rhs)
+            .into_iter()
+            .map(|s| s.to_string().into())
+            .collect::<Array>()
+            .into()
+    }
+}
+
 fn stringify_inner(value: Value) -> Rc<String> {
     match value {
         Value::String(s) => s,
@@ -203,8 +217,13 @@ fn tsv(value: Value) -> Result<Value> {
 }
 
 fn sh(value: Value) -> Result<Value> {
-    let s = stringify_inner(value);
-    let ret = shell_escape::escape(Cow::from(make_owned(s))).to_string();
+    let escape = |value: Value| {
+        shell_escape::escape(Cow::from(make_owned(stringify_inner(value)))).to_string()
+    };
+    let ret = match value {
+        Value::Array(arr) => arr.iter().map(|value| escape(value.clone())).join(" "),
+        _ => escape(value),
+    };
     Ok(ret.into())
 }
 
