@@ -412,6 +412,7 @@ lexer! {
     type Error = LexicalError;
 
     let ws = [' ' '\t' '\n'] | "\r\n";
+    let comment = '#' (_ # ['\r' '\n'])*;
     let ident_start = ['a'-'z' 'A'-'Z' '_'];
     let digit = ['0'-'9'];
     let hex_digit = $digit | ['a'-'f' 'A'-'F'];
@@ -419,6 +420,7 @@ lexer! {
 
     rule Init {
         $ws,
+        $comment,
         '+' = Token::Plus,
         '-' = Token::Minus,
         '*' = Token::Star,
@@ -643,4 +645,24 @@ mod test {
             ],
         );
     }
+
+    #[test]
+    fn test_comment() {
+        assert_lex(
+            r#""\(
+            1# This
+            + # is
+            2  #
+            )"  # comment"#,
+            &[
+                Token::StringStart,
+                Token::InterpolationStart,
+                Token::Number(1.into()),
+                Token::Plus,
+                Token::Number(2.into()),
+                Token::InterpolationEnd,
+                Token::StringEnd,
+            ],
+        );
+    }
 }
